#[non_exhaustive]pub struct SlaacState {
pub routers_seen: bool,
pub managed: bool,
pub other_config: bool,
}Expand description
What SLAAC has learned from the routers on the link, for the application.
The addresses and routes themselves are on the interface, see
Iface::ip_addrs and Stack::routes.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.routers_seen: boolAt least one router advertisement was received.
managed: boolThe last router advertisement had the “managed address configuration” flag set: addresses are available through DHCPv6.
other_config: boolThe last router advertisement had the “other configuration” flag set: other configuration (like DNS servers) is available through DHCPv6.